<?php

global $blocked;

$virusscan = 1;

$excluded = Array('jimmy@advcs.org');

$blocked = Array('bat',
'com',
'js',
'mp3',
'pif',
'scr',
'vbs');

$warning = Array('exe');

?>